@@ -16,10 +16,10 @@
 """cubicweb-trackervcs schema"""
 
 from yams.buildobjs import RelationDefinition
+from yams.reader import context
 
 from cubicweb.schema import RQLConstraint
-from cubes.vcreview.schema import Patch
-from cubes.task.schema import Task
+
 
 class source_repository(RelationDefinition):
     """version controled system holding sources for this project"""
@@ -38,18 +38,21 @@ class closed_by(RelationDefinition):
     object = 'Revision'
     constraints = [RQLConstraint('S concerns P, O from_repository R, P source_repository R')]
 
+if 'Patch' in context.defined:
+    from cubes.vcreview.schema import Patch
+    from cubes.task.schema import Task
 
-class patch_ticket(RelationDefinition):
-    subject = 'Patch'
-    object = 'Ticket'
-    constraints = [RQLConstraint('S patch_repository PR, R has_patch_repository PR, '
-                                 'O concerns P, P source_repository R')]
+    class patch_ticket(RelationDefinition):
+        subject = 'Patch'
+        object = 'Ticket'
+        constraints = [RQLConstraint('S patch_repository PR, R has_patch_repository PR, '
+                                     'O concerns P, P source_repository R')]
 
 
-class require_permission(RelationDefinition):
-    subject = ('Patch', 'Task', 'VersionContent', 'InsertionPoint')
-    object = 'CWPermission'
+    class require_permission(RelationDefinition):
+        subject = ('Patch', 'Task', 'VersionContent', 'InsertionPoint')
+        object = 'CWPermission'
 
-Task.__permissions__.update({'add': ('managers', 'staff',),
-                             'update': ('managers', 'staff', 'owners')})
-Patch.__permissions__.update({'update': ('managers', 'staff')})
+        Task.__permissions__.update({'add': ('managers', 'staff',),
+                                     'update': ('managers', 'staff', 'owners')})
+        Patch.__permissions__.update({'update': ('managers', 'staff')})
